==> fred_dnscheck-0.1.0-py3-none-any.whl: dnscheck/zonemaster.py <==
"""DNScheck Zonemaster client."""

from typing import Any, cast

import httpx

import dnscheck

from .schema import Nameserver


class ZonemasterClient:
    """Zonemaster API client."""

    def __init__(self, api_url: str) -> None:
        self.api_url = api_url
        self.request_id = 0

    def _call(self, method: str, /, *, params: dict) -> Any:
        """Make API request.

        Args:
            method: Zonemaster API method name.
            params: Request params.
        """
        self.request_id += 1
        request = {
            "jsonrpc": "2.0",
            "id": self.request_id,
            "method": method,
            "params": params,
        }

        response = httpx.post(self.api_url, json=request)
        response.raise_for_status()
        return response.json().get("result")

    def start_domain_test(self, fqdn: str, nameservers: list[Nameserver], *, profile: str | None = None) -> str:
        """Start domain test.

        Args:
            fqdn: Fully qualified domain name.
            nameservers: List of nameservers.
            profile: Zonemaster profile name.

        Returns:
            Test id.
        """
        params = {
            "client_id": "fred-dnscheck",
            "domain": fqdn,
            "client_version": dnscheck.__version__,
            "ipv6": True,
            "ipv4": True,
        }
        if profile:
            params["profile"] = profile

        params["nameservers"] = []
        for ns in nameservers:
            if ns.ip_addresses:
                cast(list, params["nameservers"]).extend([{"ns": ns.fqdn, "ip": ip} for ip in ns.ip_addresses])
            else:
                cast(list, params["nameservers"]).append({"ns": ns.fqdn})

        return cast(str, self._call("start_domain_test", params=params))

    def test_progress(self, test_id: str) -> int:
        """Fetch test progress.

        Args:
            test_id: Zonemaster test id.

        Returns:
            Percentage between 0 and 100.
        """
        return cast(int, self._call("test_progress", params={"test_id": test_id}))

    def get_test_results(self, test_id: str) -> list[dict]:
        """Get domain test results.

        Args:
            test_id: Zonemaster test id.

        Returns:
            List of test results.
        """
        result = self._call("get_test_results", params={"id": test_id, "language": "en"})
        return cast(list[dict], result["results"])

==> fred_dnscheck-0.1.1-py3-none-any.whl: dnscheck/zonemaster.py <==
"""DNScheck Zonemaster client."""

from typing import Any, cast

import httpx

import dnscheck

from .schema import Nameserver


class ZonemasterClient:
    """Zonemaster API client."""

    def __init__(self, api_url: str) -> None:
        self.api_url = api_url
        self.request_id = 0
        self.client = httpx.Client()

    def __del__(self) -> None:
        self.client.close()

    def _call(self, method: str, /, *, params: dict) -> Any:
        """Make API request.

        Args:
            method: Zonemaster API method name.
            params: Request params.
        """
        self.request_id += 1
        request = {
            "jsonrpc": "2.0",
            "id": self.request_id,
            "method": method,
            "params": params,
        }

        response = self.client.post(self.api_url, json=request)
        response.raise_for_status()
        return response.json().get("result")

    def start_domain_test(self, fqdn: str, nameservers: list[Nameserver], *, profile: str | None = None) -> str:
        """Start domain test.

        Args:
            fqdn: Fully qualified domain name.
            nameservers: List of nameservers.
            profile: Zonemaster profile name.

        Returns:
            Test id.
        """
        params = {
            "client_id": "fred-dnscheck",
            "domain": fqdn,
            "client_version": dnscheck.__version__,
            "ipv6": True,
            "ipv4": True,
        }
        if profile:
            params["profile"] = profile

        params["nameservers"] = []
        for ns in nameservers:
            if ns.ip_addresses:
                cast(list, params["nameservers"]).extend([{"ns": ns.fqdn, "ip": ip} for ip in ns.ip_addresses])
            else:
                cast(list, params["nameservers"]).append({"ns": ns.fqdn})

        return cast(str, self._call("start_domain_test", params=params))

    def test_progress(self, test_id: str) -> int:
        """Fetch test progress.

        Args:
            test_id: Zonemaster test id.

        Returns:
            Percentage between 0 and 100.
        """
        return cast(int, self._call("test_progress", params={"test_id": test_id}))

    def get_test_results(self, test_id: str) -> list[dict]:
        """Get domain test results.

        Args:
            test_id: Zonemaster test id.

        Returns:
            List of test results.
        """
        result = self._call("get_test_results", params={"id": test_id, "language": "en"})
        return cast(list[dict], result["results"])
